openwisp-network-topology
=========================

.. image:: https://github.com/openwisp/openwisp-network-topology/workflows/OpenWISP%20Network%20Topology%20CI%20Build/badge.svg?branch=master
    :target: https://github.com/openwisp/openwisp-network-topology/actions?query=OpenWISP+Network+Topology+CI+Build
    :alt: CI build status

.. image:: https://coveralls.io/repos/github/openwisp/openwisp-network-topology/badge.svg
    :target: https://coveralls.io/github/openwisp/openwisp-network-topology
    :alt: Test Coverage

.. image:: https://img.shields.io/librariesio/github/openwisp/openwisp-network-topology
    :target: https://libraries.io/github/openwisp/openwisp-network-topology#repository_dependencies
    :alt: Dependency monitoring

.. image:: https://img.shields.io/gitter/room/nwjs/nw.js.svg
    :target: https://gitter.im/openwisp/general
    :alt: chat

.. image:: https://badge.fury.io/py/openwisp-network-topology.svg
    :target: http://badge.fury.io/py/openwisp-network-topology
    :alt: Pypi Version

.. image:: https://pepy.tech/badge/openwisp-network-topology
    :target: https://pepy.tech/project/openwisp-network-topology
    :alt: downloads

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://pypi.org/project/black/
    :alt: code style: black

.. image:: https://github.com/openwisp/openwisp-network-topology/raw/docs/docs/demo_network_topology.gif
    :alt: Features Highlights

**Need a quick overview?** `Try the OpenWISP Demo
<https://openwisp.org/demo.html>`_.

**Want to help OpenWISP?** `Find out how to help us grow here
<http://openwisp.io/docs/general/help-us.html>`_.

----

OpenWISP Network Topology is a network topology collector and visualizer
web application and API, it allows to collect network topology data from
different networking software (dynamic mesh routing protocols, OpenVPN),
store it, visualize it, edit its details, it also provides hooks (a.k.a
`Django signals <https://docs.djangoproject.com/en/4.2/topics/signals/>`_)
to execute code when the status of a link changes.

For a complete overview of features, refer to the `Network Topology:
Features
<https://openwisp.io/docs/stable/network-topology/user/intro.html>`_
section of the OpenWISP documentation.

Documentation
-------------

- `Usage documentation
  <https://openwisp.io/docs/stable/network-topology/>`_
- `Developer documentation
  <https://openwisp.io/docs/stable/network-topology/developer/>`_

Contributing
------------

Please refer to the `OpenWISP contributing guidelines
<http://openwisp.io/docs/developer/contributing.html>`_.

Changelog
---------

See `CHANGES
<https://github.com/openwisp/openwisp-network-topology/blob/master/CHANGES.rst>`_.

License
-------

See `LICENSE
<https://github.com/openwisp/openwisp-network-topology/blob/master/LICENSE>`_.

This projects bundles third-party javascript libraries in its source code:

- `D3.js (BSD-3-Clause) <https://d3js.org/>`_

Support
-------

See `OpenWISP Support Channels <http://openwisp.org/support.html>`_.
